@@ -3,8 +3,6 @@ import os
 from typing import Optional, List, Tuple, Literal
 
 from python_search.entries_group import EntriesGroup
-from python_search.features import PythonSearchFeaturesSupport
-
 
 class PythonSearchConfiguration(EntriesGroup):
     """
@@ -36,7 +34,6 @@ class PythonSearchConfiguration(EntriesGroup):
         default_text_editor: Optional[str] = None,
         fzf_theme: Literal["light", "solarized"] = "light",
         custom_window_size: Optional[Tuple[int, int]] = None,
-        rerank_via_model=None,
         collect_data: bool = False,
         entry_generation=False,
         privacy_sensitive_terms: Optional[List[str]] = None,
@@ -59,17 +56,15 @@ class PythonSearchConfiguration(EntriesGroup):
         if entries_groups:
             self.aggregate_commands(entries_groups)
 
-        self.supported_features: PythonSearchFeaturesSupport = (
-            PythonSearchFeaturesSupport.default()
-        )
-
         if default_tags:
             self._default_tags = default_tags
 
         self.tags_dependent_inserter_marks = tags_dependent_inserter_marks
 
         self._initialization_time = datetime.datetime.now()
-        self._default_text_editor = default_text_editor
+        self._default_text_editor = (
+            default_text_editor if default_text_editor else "vim"
+        )
         self._fzf_theme = fzf_theme
         if custom_window_size:
             self._custom_window_size = custom_window_size
@@ -92,6 +87,9 @@ class PythonSearchConfiguration(EntriesGroup):
 
         return self._rerank_via_model_enabled
 
+    def get_python_installation_path(self):
+        return "/Users/jean.machado/miniconda3/envs/python312/bin"
+
     def get_default_tags(self):
         return self._default_tags
 
