@@ -10,7 +10,7 @@ from python_search.core_entities.core_entities import Key
 from python_search.interpreter.interpreter_matcher import InterpreterMatcher
 from python_search.logger import setup_run_key_logger
 from python_search.error.exception import notify_exception
-from python_search.search_ui.serialized_entry import (
+from python_search.search.search_ui.serialized_entry import (
     decode_serialized_data_from_entry_text,
 )
 
@@ -33,7 +33,7 @@ class EntryRunner:
         self,
         entry_text: str,
         query_used: str = "",
-        from_shortcut=False,
+        from_shortcut=None,
         wrap_in_terminal=False,
     ):
         """
@@ -45,11 +45,13 @@ class EntryRunner:
             from_shortcut means that the key execution was triggered by a desktop shortcut
         """
 
-        # if from_shortcut:
-        #    from python_search.apps.notification_ui import send_notification
-        #    send_notification(f"Arrived at shortcut")
-
         key = str(Key.from_fzf(entry_text))
+        if not key:
+            raise Exception(f"No key found {key} from {entry_text}")
+
+        if from_shortcut is True:
+            from_shortcut = "True"
+
         input_str = key
         if wrap_in_terminal:
             os.environ["new-window-non-cli"] = "1"
