@@ -1,4 +1,4 @@
-""" Centralize all exceptions definitions to help in the _entries discovery """
+"""Centralize all exceptions definitions to help in the _entries discovery"""
 
 
 class MenuException(Exception):
@@ -14,7 +14,6 @@ class CommandDoNotMatchException(Exception):
             f"Not Valid {entity.__class__.__name__} command {cmd}"
         )
 
-
 class RunException(Exception):
     @staticmethod
     def key_does_not_exist(key: str):
@@ -24,7 +23,7 @@ class RunException(Exception):
 class RegisterNewException(Exception):
     @staticmethod
     def empty_content():
-        return RegisterNewException(f"Will not register as content looks too small")
+        return RegisterNewException("Will not register as content looks too small")
 
 
 class MissingConfigException:
@@ -33,28 +32,3 @@ class MissingConfigException:
         raise MissingConfigException(
             "The python search configuration was not found. Run python_search setup to initialize a new config"
         )
-
-
-from functools import wraps
-
-
-def notify_exception():
-    """
-    Will let you know when a function is called or returned error as a desktop notification
-    """
-
-    def _(func):
-        @wraps(func)
-        def __(*args, **kwargs):
-            try:
-                result = func(*args, **kwargs)
-            except Exception as e:
-                from python_search.apps.notification_ui import send_notification
-
-                send_notification(f"Exception: {str(e)}")
-                raise e
-            return result
-
-        return __
-
-    return _
