@@ -5,7 +5,6 @@ from python_search.exceptions import CommandDoNotMatchException
 from python_search.interpreter.base import BaseInterpreter
 from python_search.interpreter.cmd import CmdInterpreter
 from python_search.interpreter.file import FileInterpreter
-from python_search.interpreter.group import GroupInterpreter
 from python_search.interpreter.python import PythonInterpreter
 from python_search.interpreter.snippet import SnippetInterpreter
 from python_search.interpreter.url import UrlInterpreter
@@ -14,13 +13,11 @@ from python_search.logger import interpreter_logger
 INTERPRETERS_IN_ORDER = [
     UrlInterpreter,
     FileInterpreter,
-    GroupInterpreter,
     SnippetInterpreter,
     PythonInterpreter,
     CmdInterpreter,
 ]
 
-
 class InterpreterMatcher:
     """
     Matches a query with an entry interpreter
@@ -48,9 +45,7 @@ class InterpreterMatcher:
         self._interpreters = INTERPRETERS_IN_ORDER
         self.logger = interpreter_logger()
 
-    def get_interpreter(
-        self, input_str: str
-    ) -> BaseInterpreter:
+    def get_interpreter(self, input_str: str) -> BaseInterpreter:
         """
         Given the string content, returns the best matched interpreter.
         Returns the instance of the matched interpreter given an text input
@@ -108,7 +103,7 @@ class InterpreterMatcher:
                 command_instance = interpreter(cmd, self.context)
                 print(f"Matched command instance {command_instance}")
                 return command_instance
-            except CommandDoNotMatchException as e:
+            except CommandDoNotMatchException:
                 pass
 
         raise Exception("Received a dict but did not match any type")
