@@ -1,13 +1,11 @@
 from typing import List, Tuple
 
 
-
 class PrivacyDetector:
-
     def __init__(self):
-        from python_search.configuration.loader import ConfigurationLoader;
-        self.configuration = ConfigurationLoader().load_config()
+        from python_search.configuration.loader import ConfigurationLoader
 
+        self.configuration = ConfigurationLoader().load_config()
 
     def has_sentitive_content(self, the_string) -> bool:
         return self.get_sensitive_content(the_string)[0]
@@ -27,10 +25,16 @@ class PrivacyDetector:
                 print(f"Found {term} in string: {entry[0:100]}")
                 sensitive_entries += 1
             total_entries += 1
-        print("Found ", sensitive_entries, " sensitive entries in a total of ", total_entries, " entries")
-
+        print(
+            "Found ",
+            sensitive_entries,
+            " sensitive entries in a total of ",
+            total_entries,
+            " entries",
+        )
 
 
 if __name__ == "__main__":
     import fire
+
     fire.Fire(PrivacyDetector)
