@@ -2,11 +2,13 @@ from python_search.search.entries_loader import EntriesLoader
 import tqdm
 import os
 
+CHROMA_DB_PATH = os.environ["HOME"] + "/.chroma_python_search.db"
+
 
 class SemanticSearch:
-
     def __init__(self, entries: dict = None, number_entries_to_return=None):
-        self.setup()
+        self.get_chroma_instance()
+        self.collection = self.client.get_collection("entries")
         if entries:
             self.entries = EntriesLoader.convert_to_list_of_entries(entries)
         else:
@@ -16,25 +18,22 @@ class SemanticSearch:
             number_entries_to_return if number_entries_to_return else 15
         )
 
-    def setup(self):
-        self.get_chroma_instance()
-        try:
-            self.collection = self.client.get_collection("entries")
-        except:
-            print("Collection not found")
-            self.collection = self.setup_entries()
-
     def get_chroma_instance(self):
         import chromadb
-        self.chroma_path = os.environ["HOME"] + "/.chroma_python_search.db"
-        self.client = chromadb.PersistentClient(path=self.chroma_path)
+
+        self.client = chromadb.PersistentClient(path=CHROMA_DB_PATH)
         return self.client
 
-
     def setup_entries(self):
-        collection = self.client.get_or_create_collection("entries")
+        print("Setting up documents")
+        existing_ids = self.client.get_or_create_collection("entries").get()["ids"]
+        missing_entries = [
+            entry for entry in self.entries if entry.key not in existing_ids
+        ]
+        print("Found ", len(missing_entries), " missing entries")
 
-        for entry in tqdm.tqdm(self.entries):
+        collection = self.client.get_or_create_collection("entries")
+        for entry in tqdm.tqdm(missing_entries):
             collection.upsert(
                 documents=[
                     entry.key + " " + entry.get_content_str() + entry.get_type_str()
@@ -48,12 +47,18 @@ class SemanticSearch:
         if not query:
             query = ""
         results = self.collection.query(
-            query_texts=[query], n_results=self.number_entries_to_return
+            query_texts=[query], n_results=self.number_entries_to_return, include=[]
         )["ids"][0]
         return results
 
 
+def chroma_run_webserver():
+    cmd = "chroma run --path " + CHROMA_DB_PATH
+    print(cmd)
+    os.system(cmd)
+
+
 if __name__ == "__main__":
     import fire
 
-    fire.Fire(SemanticSearch)
+    fire.Fire()
