@@ -4,13 +4,13 @@ import subprocess
 import shutil
 from typing import Optional
 
-from python_search.search_ui.kitty import FzfInKitty
+from python_search.search.search_ui.kitty import KittySearch
+from python_search.host_system.system_paths import SystemPaths
 
 
 class Mac:
     """
     Mac support for tool iCanHazShortcut
-
     """
 
     START_SHORTCUT_NUMBER = 1
@@ -44,12 +44,13 @@ class Mac:
             "⌃Space",
             "Launch python search",
             Mac.START_SHORTCUT_NUMBER,
-            FzfInKitty.focus_kitty_command() + " || python_search_search launch",
+            KittySearch.focus_kitty_command()
+            + " || /Users/jean.machado/miniconda3/envs/python312/bin/python_search_search launch",
         )
         Mac.START_SHORTCUT_NUMBER += 1
 
         for key, content in list(self.configuration.commands.items()):
-            if not type(content) is dict:
+            if type(content) is not dict:
                 continue
 
             if "mac_shortcut" in content:
@@ -96,7 +97,7 @@ class Mac:
     ) -> str:
         print(f"Generating shortcut for {key}")
         if custom_cmd is None:
-            custom_cmd = f'run_key "{key}"'
+            custom_cmd = f'{SystemPaths.BINARIES_PATH}/run_key "{key}"'
 
         return f"""
 
@@ -115,7 +116,7 @@ enabled = yes
 
         try:
             output = subprocess.check_output(get_pid_app, shell=True, text=True)
-        except Exception as e:
+        except Exception:
             print("Could not find PID! Restart will fail, try again.")
             return
         if len(output) < 3:
