@@ -12,7 +12,7 @@ class XFCE:
         )
 
         for key, content in list(self.configuration.commands.items()):
-            if not type(content) is dict:
+            if type(content) is not dict:
                 continue
 
             if "xfce_shortcut" in content:
